==> patch-2.5.3.6.zip: app/templates/default/js/login-scripts1.js <==
/**
 * Created by parablu-dev on 5/29/15.
 */

$(function() {

    $('.login-form').submit(function(e) {
        e.preventDefault();
        var $email = $('form input[name="username"]');
        var re = /[A-Z0-9._%+-]+@[A-Z0-9.-]+.[A-Z]{2,4}/igm;
        /*if ($email.val() == '' || re.test($email.val())){
            $('[name="username"]').removeClass('parsley-success');
            $('[name="username"]').addClass('parsley-error');
            $('.error').html('Please enter your UserID not Email address');
            $('.error').show();
            return false;
        }*/
        var html = $('.login').html();
        $('.login').attr('disabled','disabled');
        $('.login').html('Loading... <i class="fa fa-circle-o-notch fa-spin"></i>').animate();

        $('.error').hide();
        $('.error').html('');
        if ( $(this).parsley().isValid() ) {
            $.ajax({
                url: $('.login-form').attr('action'),
                data: $('form').serialize(),
                type: 'POST'
            }).done(function(data){
                var jData = $.parseJSON(data);
                if(jData.result == 'success'){
                    if(jData.redirectUrl){
                        window.location = jData.redirectUrl;
                    }else{
                        window.location = '/portal/dashboard';
                    }
                }else if(jData.result == 'fieldFail'){
                    $('.error').show();
                    for(var key in jData.msg){
                        if (jData.msg.hasOwnProperty(key)) {
                            if($('.error').html() != ''){
                                $('.error').append('<br/>'+jData.msg[key]);
                            }else{
                                $('.error').html(jData.msg[key]);
                            }
                            $('[name="'+key.toLowerCase()+'"]').removeClass('parsley-success');
                            $('[name="'+key.toLowerCase()+'"]').addClass('parsley-error');
                        }
                    }
                    $('.login').removeAttr('disabled');
                    $('.login').html(html);
                }else{
                    $('.login').removeAttr('disabled');
                    $('.login').html(html);
                    $('[name="username"]').removeClass('parsley-success');
                    $('[name="username"]').addClass('parsley-error');
                    $('[name="password"]').removeClass('parsley-success');
                    $('[name="password"]').addClass('parsley-error');
                    $('.error').show();
                    $('.error').html(jData.msg);
                }
            }).fail(function(data){
                if(data.status == 424){
                    $('.error').show();
                    $('.error').html('Either username or password is wrong, please check again if still not working contact your administrator');
                    $('.login').removeAttr('disabled');
                    $('.login').html(html);
                    $('[name="username"]').removeClass('parsley-success');
                    $('[name="username"]').addClass('parsley-error');
                    $('[name="password"]').removeClass('parsley-success');
                    $('[name="password"]').addClass('parsley-error');
                    $('.error').show();
                    $('.error').html(jData.msg);
                }else if(data.status == 503){
                    $('.error').show();
                    $('.error').html('Server is down please contact your administrator');
                    $('.login').removeAttr('disabled');
                    $('.login').html(html);
                    $('[name="username"]').removeClass('parsley-success');
                    $('[name="username"]').addClass('parsley-error');
                    $('[name="password"]').removeClass('parsley-success');
                    $('[name="password"]').addClass('parsley-error');
                    $('.error').show();
                    $('.error').html(jData.msg);
                }
            });
        }
    });

    $('.passwordRest').submit(function(e) {
        e.preventDefault();
        var html = $('.submit').html();
        $('.submit').attr('disabled','disabled');
        $('.submit').html('Loading... <i class="fa fa-circle-o-notch fa-spin"></i>').animate();

        $('#status').hide();
        $('#status').html('');
        if ( $(this).parsley().isValid() ) {
            $.ajax({
                url: $('.passwordRest').attr('action'),
                data: $('form').serialize(),
                type: 'POST'
            }).done(function(data){
                var jData = JSON.parse(data);
                if(jData.result == 'success'){
                    $('#status').show();
                    $('#status').html(jData.msg);
                    $('#status').removeClass('error');
                    $('#status').addClass('success');
                    setTimeout(function(){
                        window.location.href = jData.location;
                    }, 5000);
                }else if(jData.result == 'fail'){
                    $('#status').show();
                    $('#status').html(jData.msg);
                    $('#status').removeClass('success');
                    $('#status').addClass('error');
                }
                $('.submit').removeAttr('disabled');
                $('.submit').html(html);
            }).fail(function(data){
                $('.submit').removeAttr('disabled');
                $('.submit').html(html);
                if(data.status == 424){
                    $('#status').show();
                    $('#status').html('Either username or password is wrong, please check again if still not working contact your administrator');
                    $('#status').addClass('error');
                    $('#status').removeClass('success');
                    $('.login').removeAttr('disabled');
                    $('.login').html(html);
                    $('[name="cloudName"]').removeClass('parsley-success');
                    $('[name="cloudName"]').addClass('parsley-error');
                    $('[name="userName"]').removeClass('parsley-success');
                    $('[name="userName"]').addClass('parsley-error');
                }else if(data.status == 503){
                    $('#status').show();
                    $('#status').html('Server is down please contact your administrator');
                    $('#status').addClass('error');
                    $('#status').removeClass('success');
                    $('.login').removeAttr('disabled');
                    $('.login').html(html);
                    $('[name="cloudName"]').removeClass('parsley-success');
                    $('[name="cloudName"]').addClass('parsley-error');
                    $('[name="userName"]').removeClass('parsley-success');
                    $('[name="userName"]').addClass('parsley-error');
                }
            });
        }
    });

    $('.restPassword').submit(function(e) {

        e.preventDefault();
        var html = $('.submit').html();
        $('.submit').attr('disabled','disabled');
        $('.submit').html('Loading... <i class="fa fa-circle-o-notch fa-spin"></i>').animate();

        $('#status').hide();
        $('#status').html('');
        if ( $(this).parsley().isValid() ) {
            $.ajax({
                url: $('.restPassword').attr('action'),
                data: $('form').serialize(),
                type: 'POST'
            }).done(function(data){
                console.log(data);
                var jData = JSON.parse(data);
                if(jData.result == 'success'){
                    $('#status').show();
                    $('#status').html(jData.msg);
                    $('#status').removeClass('error');
                    $('#status').addClass('success');
                    setTimeout(function(){
                        window.location.href = jData.location;
                    }, 5000);
                }
                $('.submit').removeAttr('disabled');
                $('.submit').html(html);
            }).fail(function(data){
                $('.submit').removeAttr('disabled');
                $('.submit').html(html);
                if(data.status == 424){
                    $('#status').show();
                    $('#status').html('Either username or password is wrong, please check again if still not working contact your administrator');
                    $('#status').addClass('error');
                    $('#status').removeClass('success');
                    $('.login').removeAttr('disabled');
                    $('.login').html(html);
                    $('[name="password"]').removeClass('parsley-success');
                    $('[name="password"]').addClass('parsley-error');
                    $('[name="rePassword"]').removeClass('parsley-success');
                    $('[name="rePassword"]').addClass('parsley-error');
                }else if(data.status == 503){
                    $('#status').show();
                    $('#status').html('Server is down please contact your administrator');
                    $('#status').addClass('error');
                    $('#status').removeClass('success');
                    $('.login').removeAttr('disabled');
                    $('.login').removeAttr('disabled');
                    $('.login').html(html);
                    $('[name="password"]').removeClass('parsley-success');
                    $('[name="password"]').addClass('parsley-error');
                    $('[name="rePassword"]').removeClass('parsley-success');
                    $('[name="rePassword"]').addClass('parsley-error');
                }
            });
        }
    });
});

$( ".toggle-password" ).mousedown(function() {
  $("#password").attr("type", "text");
$(this).toggleClass("fa-eye-slash fa-eye");
});

$( ".toggle-password" ).mouseup(function() {
  $("#password").attr("type", "password");
$(this).toggleClass("fa-eye fa-eye-slash");
});

$(".aa").click(function(){
    $(".aa").toggleClass("hide");
$(".bb").toggleClass("show");
});

==> patch-2.5.3.18_3.zip: app/templates/default/js/login-scripts1.js <==
/**
 * Created by parablu-dev on 5/29/15.
 */

$(function() {

    $('.login-form').submit(function(e) {
        e.preventDefault();
        var $email = $('form input[name="username"]');
        var re = /[A-Z0-9._%+-]+@[A-Z0-9.-]+.[A-Z]{2,4}/igm;
        /*if ($email.val() == '' || re.test($email.val())){
            $('[name="username"]').removeClass('parsley-success');
            $('[name="username"]').addClass('parsley-error');
            $('.error').html('Please enter your UserID not Email address');
            $('.error').show();
            return false;
        }*/
        var html = $('.login').html();
        $('.login').attr('disabled','disabled');
        $('.login').html('Loading... <i class="fa fa-circle-o-notch fa-spin"></i>').animate();

        $('.error').hide();
        $('.error').html('');
        if ( $(this).parsley().isValid() ) {
            $.ajax({
                url: $('.login-form').attr('action'),
                data: $('form').serialize(),
                type: 'POST'
            }).done(function(data){
                var jData = $.parseJSON(data);
                if(jData.result == 'success'){
                    if(jData.redirectUrl){
                        window.location = jData.redirectUrl;
                    }else{
                        window.location = '/portal/dashboard';
                    }
                }else if(jData.result == 'fieldFail'){
                    $('.error').show();
                    for(var key in jData.msg){
                        if (jData.msg.hasOwnProperty(key)) {
                            if($('.error').html() != ''){
                                $('.error').append('<br/>'+jData.msg[key]);
                            }else{
                                $('.error').html(jData.msg[key]);
                            }
                            $('[name="'+key.toLowerCase()+'"]').removeClass('parsley-success');
                            $('[name="'+key.toLowerCase()+'"]').addClass('parsley-error');
                        }
                    }
                    $('.login').removeAttr('disabled');
                    $('.login').html(html);
                }else{
                    $('.login').removeAttr('disabled');
                    $('.login').html(html);
                    $('[name="username"]').removeClass('parsley-success');
                    $('[name="username"]').addClass('parsley-error');
                    $('[name="password"]').removeClass('parsley-success');
                    $('[name="password"]').addClass('parsley-error');
                    $('.error').show();
                    $('.error').html(jData.msg);
                }
            }).fail(function(data){
                if(data.status == 424){
                    $('.error').show();
                    $('.error').html('Either username or password is wrong, please check again if still not working contact your administrator');
                    $('.login').removeAttr('disabled');
                    $('.login').html(html);
                    $('[name="username"]').removeClass('parsley-success');
                    $('[name="username"]').addClass('parsley-error');
                    $('[name="password"]').removeClass('parsley-success');
                    $('[name="password"]').addClass('parsley-error');
                    $('.error').show();
                    $('.error').html(jData.msg);
                }else if(data.status == 503){
                    $('.error').show();
                    $('.error').html('Server is down please contact your administrator');
                    $('.login').removeAttr('disabled');
                    $('.login').html(html);
                    $('[name="username"]').removeClass('parsley-success');
                    $('[name="username"]').addClass('parsley-error');
                    $('[name="password"]').removeClass('parsley-success');
                    $('[name="password"]').addClass('parsley-error');
                    $('.error').show();
                    $('.error').html(jData.msg);
                }
            });
        }
    });
    
    $('.captcha-form').submit(function(e) {
        e.preventDefault();
        var html = $('.loginCaptcha').html();
        $('.loginCaptcha').attr('disabled','disabled');
        $('.loginCaptcha').html('Loading... <i class="fa fa-circle-o-notch fa-spin"></i>').animate();
        $('.error').hide();
        $('.error').html('');
        if ( $(this).parsley().isValid() ) {
            $.ajax({
                url: $('.captcha-form').attr('action'),
                data: $('form').serialize(),
                type: 'POST'
            }).done(function(data){
                var jData = $.parseJSON(data);
                if(jData.result == 'success'){
                    if(jData.redirectUrl){
                        window.location = jData.redirectUrl;
                    }else{
                        window.location = '/portal/dashboard';
                    }
                }else if(jData.result == 'fieldFail'){
                    $('.error').show();
                    for(var key in jData.msg){
                        if (jData.msg.hasOwnProperty(key)) {
                            if($('.error').html() != ''){
                                $('.error').append('<br/>'+jData.msg[key]);
                            }else{
                                $('.error').html(jData.msg[key]);
                            }
                            $('[name="'+key.toLowerCase()+'"]').removeClass('parsley-success');
                            $('[name="'+key.toLowerCase()+'"]').addClass('parsley-error');
                        }
                    }
                    $('.loginCaptcha').removeAttr('disabled');
                    $('.loginCaptcha').html(html);
                }else{
                    $('.loginCaptcha').removeAttr('disabled');
                    $('.loginCaptcha').html(html);
                    $('.error').show();
                    $('.error').html(jData.msg);
                }
            }).fail(function(data){
                if(data.status == 424){
                    $('.error').show();
                    $('.error').html('Either username or password is wrong, please check again if still not working contact your administrator');
                    $('.loginCaptcha').removeAttr('disabled');
                    $('.loginCaptcha').html(html);
                    $('.error').show();
                    $('.error').html(jData.msg);
                }else if(data.status == 503){
                    $('.error').show();
                    $('.error').html('Server is down please contact your administrator');
                    $('.loginCaptcha').removeAttr('disabled');
                    $('.loginCaptcha').html(html);
                    $('.error').show();
                    $('.error').html(jData.msg);
                }
            });
        }
    });
$('.mfa-form').submit(function(e) {
        e.preventDefault();
        var html = $('.loginMFA').html();
        $('.loginMFA').attr('disabled','disabled');
        $('.loginMFA').html('Loading... <i class="fa fa-circle-o-notch fa-spin"></i>').animate();
        $('.error').hide();
        $('.error').html('');
        if ( $(this).parsley().isValid() ) {
            $.ajax({
                url: $('.mfa-form').attr('action'),
                data: $('form').serialize(),
                type: 'POST'
            }).done(function(data){
                var jData = $.parseJSON(data);
                if(jData.result == 'success'){
                    if(jData.redirectUrl){
                        window.location = jData.redirectUrl;
                    }else{
                        window.location = '/portal/dashboard';
                    }
                }else if(jData.result == 'fieldFail'){
                    $('.error').show();
                    for(var key in jData.msg){
                        if (jData.msg.hasOwnProperty(key)) {
                            if($('.error').html() != ''){
                                $('.error').append('<br/>'+jData.msg[key]);
                            }else{
                                $('.error').html(jData.msg[key]);
                            }
                            $('[name="'+key.toLowerCase()+'"]').removeClass('parsley-success');
                            $('[name="'+key.toLowerCase()+'"]').addClass('parsley-error');
                        }
                    }
                    $('.loginMFA').removeAttr('disabled');
                    $('.loginMFA').html(html);
                }else{
                    $('.loginMFA').removeAttr('disabled');
                    $('.loginMFA').html(html);
                    $('.error').show();
                    $('.error').html(jData.msg);
                }
            }).fail(function(data){
                if(data.status == 424){
                    $('.error').show();
                    $('.error').html('Either username or password is wrong, please check again if still not working contact your administrator');
                    $('.loginMFA').removeAttr('disabled');
                    $('.loginMFA').html(html);
                    $('.error').show();
                    $('.error').html(jData.msg);
                }else if(data.status == 503){
                    $('.error').show();
                    $('.error').html('Server is down please contact your administrator');
                    $('.loginMFA').removeAttr('disabled');
                    $('.loginMFA').html(html);
                    $('.error').show();
                    $('.error').html(jData.msg);
                }
            });
        }
    });

    $('.passwordRest').submit(function(e) {
        e.preventDefault();
        var html = $('.submit').html();
        $('.submit').attr('disabled','disabled');
        $('.submit').html('Loading... <i class="fa fa-circle-o-notch fa-spin"></i>').animate();

        $('#status').hide();
        $('#status').html('');
        if ( $(this).parsley().isValid() ) {
            $.ajax({
                url: $('.passwordRest').attr('action'),
                data: $('form').serialize(),
                type: 'POST'
            }).done(function(data){
                var jData = JSON.parse(data);
                if(jData.result == 'success'){
                    $('#status').show();
                    $('#status').html(jData.msg);
                    $('#status').removeClass('error');
                    $('#status').addClass('success');
                    setTimeout(function(){
                        window.location.href = jData.location;
                    }, 5000);
                }else if(jData.result == 'fail'){
                    $('#status').show();
                    $('#status').html(jData.msg);
                    $('#status').removeClass('success');
                    $('#status').addClass('error');
                }
                $('.submit').removeAttr('disabled');
                $('.submit').html(html);
            }).fail(function(data){
                $('.submit').removeAttr('disabled');
                $('.submit').html(html);
                if(data.status == 424){
                    $('#status').show();
                    $('#status').html('Either username or password is wrong, please check again if still not working contact your administrator');
                    $('#status').addClass('error');
                    $('#status').removeClass('success');
                    $('.login').removeAttr('disabled');
                    $('.login').html(html);
                    $('[name="cloudName"]').removeClass('parsley-success');
                    $('[name="cloudName"]').addClass('parsley-error');
                    $('[name="userName"]').removeClass('parsley-success');
                    $('[name="userName"]').addClass('parsley-error');
                }else if(data.status == 503){
                    $('#status').show();
                    $('#status').html('Server is down please contact your administrator');
                    $('#status').addClass('error');
                    $('#status').removeClass('success');
                    $('.login').removeAttr('disabled');
                    $('.login').html(html);
                    $('[name="cloudName"]').removeClass('parsley-success');
                    $('[name="cloudName"]').addClass('parsley-error');
                    $('[name="userName"]').removeClass('parsley-success');
                    $('[name="userName"]').addClass('parsley-error');
                }
            });
        }
    });

    $('.restPassword').submit(function(e) {

        e.preventDefault();
        var html = $('.submit').html();
        $('.submit').attr('disabled','disabled');
        $('.submit').html('Loading... <i class="fa fa-circle-o-notch fa-spin"></i>').animate();

        $('#status').hide();
        $('#status').html('');
        if ( $(this).parsley().isValid() ) {
            $.ajax({
                url: $('.restPassword').attr('action'),
                data: $('form').serialize(),
                type: 'POST'
            }).done(function(data){
                console.log(data);
                var jData = JSON.parse(data);
                if(jData.result == 'success'){
                    $('#status').show();
                    $('#status').html(jData.msg);
                    $('#status').removeClass('error');
                    $('#status').addClass('success');
                    setTimeout(function(){
                        window.location.href = jData.location;
                    }, 5000);
                }
                $('.submit').removeAttr('disabled');
                $('.submit').html(html);
            }).fail(function(data){
                $('.submit').removeAttr('disabled');
                $('.submit').html(html);
                if(data.status == 424){
                    $('#status').show();
                    $('#status').html('Either username or password is wrong, please check again if still not working contact your administrator');
                    $('#status').addClass('error');
                    $('#status').removeClass('success');
                    $('.login').removeAttr('disabled');
                    $('.login').html(html);
                    $('[name="password"]').removeClass('parsley-success');
                    $('[name="password"]').addClass('parsley-error');
                    $('[name="rePassword"]').removeClass('parsley-success');
                    $('[name="rePassword"]').addClass('parsley-error');
                }else if(data.status == 503){
                    $('#status').show();
                    $('#status').html('Server is down please contact your administrator');
                    $('#status').addClass('error');
                    $('#status').removeClass('success');
                    $('.login').removeAttr('disabled');
                    $('.login').removeAttr('disabled');
                    $('.login').html(html);
                    $('[name="password"]').removeClass('parsley-success');
                    $('[name="password"]').addClass('parsley-error');
                    $('[name="rePassword"]').removeClass('parsley-success');
                    $('[name="rePassword"]').addClass('parsley-error');
                }
            });
        }
    });
});

$( ".toggle-password" ).mousedown(function() {
  $("#password").attr("type", "text");
$(this).toggleClass("fa-eye-slash fa-eye");
});

$( ".toggle-password" ).mouseup(function() {
  $("#password").attr("type", "password");
$(this).toggleClass("fa-eye fa-eye-slash");
});

$(".aa").click(function(){
    $(".aa").toggleClass("hide");
$(".bb").toggleClass("show");
});
